CachedPresence class

Constructors

CachedPresence(PresenceType presence, int? lastActiveAgo, String? statusMsg, bool? currentlyActive, String userid)
CachedPresence.fromJson(Map<String, Object?> json)
factory
CachedPresence.fromMatrixEvent(Presence event)
CachedPresence.fromPresenceResponse(GetPresenceResponse event, String userid)
CachedPresence.neverSeen(String userid)

Properties

currentlyActive ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastActiveTimestamp ↔ DateTime?
getter/setter pair
presence ↔ PresenceType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusMsg ↔ String?
getter/setter pair
userid ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toPresence() → Presence
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited