CallBackend class abstract

Implementers

Constructors

CallBackend({required String type})
CallBackend.fromJson(Map<String, Object?> json)
factory

Properties

activeSpeaker → CallParticipant?
no setter
e2eeEnabled → bool
no setter
hashCode → int
The hash code for this object.
no setteroverride
isLocalVideoMuted → bool
no setter
isMicrophoneMuted → bool
no setter
localScreenshareStream → WrappedMediaStream?
no setter
localUserMediaStream → WrappedMediaStream?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenShareStreams → List<WrappedMediaStream>
no setter
type ↔ String
getter/setter pair
userMediaStreams → List<WrappedMediaStream>
no setter

Methods

dispose(GroupCallSession groupCall) → Future<void>
getCurrentFeeds() → List<Map<String, String>>?
initLocalStream(GroupCallSession groupCall, {WrappedMediaStream? stream}) → Future<WrappedMediaStream?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCallEncryption(GroupCallSession groupCall, String userId, String deviceId, Map<String, dynamic> content) → Future<void>
onCallEncryptionKeyRequest(GroupCallSession groupCall, String userId, String deviceId, Map<String, dynamic> content) → Future<void>
onLeftParticipant(GroupCallSession groupCall, List<CallParticipant> anyLeft) → Future<void>
onNewParticipant(GroupCallSession groupCall, List<CallParticipant> anyJoined) → Future<void>
preShareKey(GroupCallSession groupCall) → Future<void>
requestEncrytionKey(GroupCallSession groupCall, List<CallParticipant> remoteParticipants) → Future<void>
setDeviceMuted(GroupCallSession groupCall, bool muted, MediaInputKind kind) → Future<void>
setScreensharingEnabled(GroupCallSession groupCall, bool enabled, String desktopCapturerSourceId) → Future<void>
setupP2PCallsWithExistingMembers(GroupCallSession groupCall) → Future<void>
setupP2PCallWithNewMember(GroupCallSession groupCall, CallParticipant rp, CallMembership mem) → Future<void>
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited
updateMediaDeviceForCalls() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
override