CallTimeouts class

Constructors

CallTimeouts({Duration defaultCallEventLifetime = const Duration(seconds: 10), Duration callInviteLifetime = const Duration(seconds: 60), Duration iceGatheringDelay = const Duration(milliseconds: 200), Duration delayBeforeOffer = const Duration(milliseconds: 100), Duration updateExpireTsTimerDuration = const Duration(minutes: 2), Duration expireTsBumpDuration = const Duration(minutes: 6), Duration activeSpeakerInterval = const Duration(seconds: 5), Duration makeKeyOnLeaveDelay = const Duration(seconds: 4), Duration makeKeyOnJoinDelay = const Duration(seconds: 8), Duration useKeyDelay = const Duration(seconds: 4), Duration delayedEventApplyLeave = const Duration(seconds: 18), Duration delayedEventRestart = const Duration(seconds: 4)})

Properties

activeSpeakerInterval Duration
Update the active speaker value
final
callInviteLifetime Duration
The length of time a call can be ringing for.
final
defaultCallEventLifetime Duration
The default life time for call events, in millisecond.
final
delayBeforeOffer Duration
Delay before createOffer.
final
delayedEventApplyLeave Duration
After how long the homeserver should send the delayed leave event which gracefully leaves you from the call
final
delayedEventRestart Duration
How often the delayed event should be restarted on the homeserver
final
expireTsBumpDuration Duration
the expiresTs bump
final
hashCode int
The hash code for this object.
no setterinherited
iceGatheringDelay Duration
The delay for ice gathering.
final
makeKeyOnJoinDelay Duration
A delay used for joins, only creates new keys if last new created key was before $makeKeyDelay duration, or it was recently made and it's safe to send that The bigger this is the easier key sharing would be, but also less secure Not used if ratcheting is enabled
final
makeKeyOnLeaveDelay Duration
A delay after a member leaves before we create and publish a new key, because people tend to leave calls at the same time
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateExpireTsTimerDuration Duration
How often to update the expiresTs
final
useKeyDelay Duration
The delay between creating and sending a new key and starting to encrypt with it. This gives others a chance to receive the new key to minimise the chance they don't get media they can't decrypt. The total time between a member leaving and the call switching to new keys is therefore makeKeyDelay + useKeyDelay
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited