useKeyDelay property

Duration useKeyDelay
final

The delay between creating and sending a new key and starting to encrypt with it. This gives others a chance to receive the new key to minimise the chance they don't get media they can't decrypt. The total time between a member leaving and the call switching to new keys is therefore makeKeyDelay + useKeyDelay

Implementation

final Duration useKeyDelay;