CommandArgs class

Constructors

CommandArgs({required String msg, String? editEventId, Event? inReplyTo, required Client client, Room? room, String? txid, String? threadRootEventId, String? threadLastEventId})

Properties

client ↔ Client
getter/setter pair
editEventId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inReplyTo ↔ Event?
getter/setter pair
msg ↔ String
getter/setter pair
room ↔ Room?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadLastEventId ↔ String?
getter/setter pair
threadRootEventId ↔ String?
getter/setter pair
txid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited