GroupCallErrorCode enum
Values
- userMediaFailed → const GroupCallErrorCode
-
An error code when there is no local mic/camera to use. This may be because the hardware isn't plugged in, or the user has explicitly denied access.
const GroupCallErrorCode('user_media_failed') - unknownError → const GroupCallErrorCode
-
Some other failure occurred that meant the client was unable to continue the call rather than the user choosing to end it.
const GroupCallErrorCode('unknownError')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - reason → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GroupCallErrorCode> - A constant List of the values in this enum, in order of their declaration.