JoinRules enum
- Inheritance
- Available extensions
Values
- public → const JoinRules
-
const JoinRules('public') - knock → const JoinRules
-
const JoinRules('knock') - invite → const JoinRules
-
const JoinRules('invite') - private → const JoinRules
-
const JoinRules('private') - restricted → const JoinRules
-
const JoinRules('restricted') - knockRestricted → const JoinRules
-
const JoinRules('knock_restricted')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
Methods
-
getLocalizedString(
MatrixLocalizations i18n) → String -
Available on JoinRules, provided by the JoinRulesDisplayString extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited