MatrixVideoThumbnailResponse class

Constructors

MatrixVideoThumbnailResponse({required Uint8List bytes, required int width, required int height, String? mimeType, String? blurhash, int? originalWidth, int? originalHeight, int? duration})
const

Properties

blurhash String?
final
bytes Uint8List
final
duration int?
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
mimeType String?
final
originalHeight int?
final
originalWidth int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited