NativeImplementationsIsolate class
a NativeImplementations based on Flutter's compute function
this implementations simply wraps the given compute function around the implementation of NativeImplementations.dummy
- Inheritance
-
- Object
- NativeImplementations
- NativeImplementationsIsolate
Constructors
-
NativeImplementationsIsolate(ComputeCallback compute, {Future<
void> vodozemacInit()?})
Properties
- compute → ComputeCallback
-
pass by Flutter's compute function here
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
vodozemacInit
→ Future<
void> Function()? -
final
Methods
-
calcImageMetadata(
Uint8List bytes, {bool retryInDummy = false}) → FutureOr< MatrixImageFileResizedResponse?> -
override
-
checkSecretStorageKey(
CheckSecretStorageKeyArgs args) → Future< bool> -
override
-
decryptFile(
EncryptedFile file, {bool retryInDummy = true}) → Future< Uint8List?> -
override
-
generateUploadKeys(
GenerateUploadKeysArgs args, {bool retryInDummy = true}) → Future< RoomKeys> -
override
-
keyFromPassphrase(
KeyFromPassphraseArgs args, {bool retryInDummy = true}) → Future< Uint8List> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
this implementation will catch any non-implemented method
inherited
-
runInBackground<
T, U> (FutureOr< T> function(U arg), U arg) → Future<T> -
shrinkImage(
MatrixImageFileResizeArguments args, {bool retryInDummy = false}) → Future< MatrixImageFileResizedResponse?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited