postLoad method

Future<void> postLoad()

Post-loads the room. This load all the missing state events for the room from the database If the room has already been loaded, this does nothing.

Implementation

Future<void> postLoad() async {
  if (!partial) {
    return;
  }
  final allStates =
      await client.database.getUnimportantRoomEventStatesForRoom(
    client.importantStateEvents.toList(),
    this,
  );

  for (final state in allStates) {
    setState(state);
  }
  partial = false;
}