WrappedMediaStream class

Wrapped MediaStream, used to adapt Widget to display

Constructors

WrappedMediaStream({MediaStream? stream, RTCPeerConnection? pc, required Room room, required CallParticipant participant, required String purpose, required Client client, required bool audioMuted, required bool videoMuted, required bool isGroupCall, required VoIP voip})

Properties

audioMuted ↔ bool
getter/setter pair
avatarName → String
no setter
avatarUrl → Uri?
no setter
client → Client
final
displayName → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
isGroupCall → bool
final
onMuteStateChanged → CachedStreamController<WrappedMediaStream>
final
onStreamChanged → CachedStreamController<MediaStream>
final
participant → CallParticipant
final
pc → RTCPeerConnection?
final
purpose ↔ String
Current stream type, usermedia or screen-sharing
getter/setter pair
room → Room
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stopped ↔ bool
getter/setter pair
stream ↔ MediaStream?
getter/setter pair
title → String
for debug
no setter
videoMuted ↔ bool
getter/setter pair
voip → VoIP
final

Methods

dispose() → Future<void>
getUser() → User
isAudioMuted() → bool
isLocal() → bool
isVideoMuted() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAudioMuted(bool muted) → void
setNewStream(MediaStream newStream) → void
setVideoMuted(bool muted) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited