reportRoom method

Future<void> reportRoom(
  1. String roomId,
  2. String reason
)

Reports a room as inappropriate to the server, which may then notify the appropriate people. How such information is delivered is left up to implementations. The caller is not required to be joined to the room to report it.

Clients could infer whether a reported room exists based on the 404 response. Homeservers that wish to conceal this information MAY return 200 responses regardless of the existence of the reported room.

Furthermore, it might be possible for clients to deduce whether a reported room exists by timing the response. This is because only a report for an existing room will require the homeserver to do further processing. To combat this, homeservers MAY add a random delay when generating a response.

roomId The room being reported.

reason The reason the room is being reported. May be blank.

Implementation

Future<void> reportRoom(String roomId, String reason) async {
  final requestUri = Uri(
    path: '_matrix/client/v3/rooms/${Uri.encodeComponent(roomId)}/report',
  );
  final request = Request('POST', baseUri!.resolveUri(requestUri));
  request.headers['authorization'] = 'Bearer ${bearerToken!}';
  request.headers['content-type'] = 'application/json';
  request.bodyBytes = utf8.encode(jsonEncode({'reason': reason}));
  final response = await httpClient.send(request);
  final responseBody = await response.stream.toBytes();
  if (response.statusCode != 200) unexpectedResponse(response, responseBody);
  final responseString = utf8.decode(responseBody);
  final json = jsonDecode(responseString);
  return ignore(json);
}