AccountManagementActionsSupported enum
An action that the account management URL supports.
Values
- orgMatrixAccountDeactivate → const AccountManagementActionsSupported
-
const AccountManagementActionsSupported('org.matrix.account_deactivate') - orgMatrixCrossSigningReset → const AccountManagementActionsSupported
-
const AccountManagementActionsSupported('org.matrix.cross_signing_reset') - orgMatrixDeviceDelete → const AccountManagementActionsSupported
-
const AccountManagementActionsSupported('org.matrix.device_delete') - orgMatrixDeviceView → const AccountManagementActionsSupported
-
const AccountManagementActionsSupported('org.matrix.device_view') - orgMatrixDevicesList → const AccountManagementActionsSupported
-
const AccountManagementActionsSupported('org.matrix.devices_list') - orgMatrixProfile → const AccountManagementActionsSupported
-
const AccountManagementActionsSupported('org.matrix.profile')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AccountManagementActionsSupported> - A constant List of the values in this enum, in order of their declaration.