AccountModerationCapability class

Properties

hashCode int
The hash code for this object.
no setteroverride
lock bool?
true if the user can lock a user via PUT /admin/lock/{userId}, false otherwise.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suspend bool?
true if the user can suspend a user via PUT /admin/suspend/{userId}, false otherwise.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override