lock property
true if the user can lock a user via PUT /admin/lock/{userId},
false otherwise.
Defaults to false.
Implementation
bool? lock;
true if the user can lock a user via PUT /admin/lock/{userId},
false otherwise.
Defaults to false.
bool? lock;