suspend property
true if the user can suspend a user via PUT /admin/suspend/{userId},
false otherwise.
Defaults to false.
Implementation
bool? suspend;
true if the user can suspend a user via PUT /admin/suspend/{userId},
false otherwise.
Defaults to false.
bool? suspend;