mAccountModeration property

AccountModerationCapability? mAccountModeration
getter/setter pair

Capability to indicate if the user can perform account moderation actions via server administration endpoints.

This property should be omitted altogether if suspend and lock would be false.

Implementation

AccountModerationCapability? mAccountModeration;