mForgetForcedUponLeave property
Capability to indicate if the server automatically forgets rooms once the user leaves.
Implementation
BooleanCapability? mForgetForcedUponLeave;
Capability to indicate if the server automatically forgets rooms once the user leaves.
BooleanCapability? mForgetForcedUponLeave;