GetAuthMetadataResponse class
Constructors
-
GetAuthMetadataResponse({List<
AccountManagementActionsSupported> ? accountManagementActionsSupported, Uri? accountManagementUri, required Uri authorizationEndpoint, required List<String> codeChallengeMethodsSupported, Uri? deviceAuthorizationEndpoint, required List<String> grantTypesSupported, required Uri issuer, List<String> ? promptValuesSupported, required Uri registrationEndpoint, required List<String> responseModesSupported, required List<String> responseTypesSupported, required Uri revocationEndpoint, required Uri tokenEndpoint}) -
GetAuthMetadataResponse.fromJson(Map<
String, Object?> json)
Properties
-
accountManagementActionsSupported
↔ List<
AccountManagementActionsSupported> ? -
List of actions that the account management URL supports.
getter/setter pair
- accountManagementUri ↔ Uri?
-
The URL where the user is able to access the account management capabilities
of the homeserver.
getter/setter pair
-
URL of the authorization endpoint, necessary to use the authorization code
grant.
getter/setter pair
-
codeChallengeMethodsSupported
↔ List<
String> -
List of OAuth 2.0 Proof Key for Code Exchange (PKCE) code challenge methods
that the server supports at the authorization endpoint.
getter/setter pair
- deviceAuthorizationEndpoint ↔ Uri?
-
URL of the device authorization endpoint, as defined in
RFC 8628, necessary to use
the device authorization grant.
getter/setter pair
-
grantTypesSupported
↔ List<
String> -
List of OAuth 2.0 grant type strings that the server supports at the token
endpoint.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- issuer ↔ Uri
-
The authorization server's issuer identifier, which is a URL that uses the
httpsscheme and has no query or fragment components.getter/setter pair -
promptValuesSupported
↔ List<
String> ? -
List of OpenID Connect prompt values that the server supports at the
authorization endpoint.
getter/setter pair
- registrationEndpoint ↔ Uri
-
URL of the client registration endpoint, necessary to perform dynamic
registration of a client.
getter/setter pair
-
responseModesSupported
↔ List<
String> -
List of OAuth 2.0 response mode strings that the server supports at the
authorization endpoint.
getter/setter pair
-
responseTypesSupported
↔ List<
String> -
List of OAuth 2.0 response type strings that the server supports at the
authorization endpoint.
getter/setter pair
- revocationEndpoint ↔ Uri
-
URL of the revocation endpoint, necessary to log out a client by invalidating
its access and refresh tokens.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenEndpoint ↔ Uri
-
URL of the token endpoint, used by the grants.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override