accountManagementUri property
The URL where the user is able to access the account management capabilities of the homeserver.
This is an extension defined in this specification.
Implementation
Uri? accountManagementUri;
The URL where the user is able to access the account management capabilities of the homeserver.
This is an extension defined in this specification.
Uri? accountManagementUri;