authorizationEndpoint property
URL of the authorisation endpoint, necessary to use the authorisation code grant.
Implementation
Uri authorizationEndpoint;
URL of the authorisation endpoint, necessary to use the authorisation code grant.
Uri authorizationEndpoint;