codeChallengeMethodsSupported property

List<String> codeChallengeMethodsSupported
getter/setter pair

List of OAuth 2.0 Proof Key for Code Exchange (PKCE) code challenge methods that the server supports at the authorisation endpoint.

This array MUST contain at least the S256 value, for improved security in the authorisation code grant.

Implementation

List<String> codeChallengeMethodsSupported;