deviceAuthorizationEndpoint property
URL of the device authorization endpoint, as defined in RFC 8628, necessary to use the device authorization grant.
Implementation
Uri? deviceAuthorizationEndpoint;
URL of the device authorization endpoint, as defined in RFC 8628, necessary to use the device authorization grant.
Uri? deviceAuthorizationEndpoint;