responseModesSupported property

List<String> responseModesSupported
getter/setter pair

List of OAuth 2.0 response mode strings that the server supports at the authorisation endpoint.

This array MUST contain at least the query and fragment values, for improved security in the authorisation code grant.

Implementation

List<String> responseModesSupported;