PreviewForUrl class
Constructors
-
PreviewForUrl({int? matrixImageSize, Uri? ogImage, Map<
String, Object?> additionalProperties = const {}}) -
PreviewForUrl.fromJson(Map<
String, Object?> json)
Properties
-
additionalProperties
↔ Map<
String, Object?> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- matrixImageSize ↔ int?
-
The byte-size of the image. Omitted if there is no image attached.
getter/setter pair
- ogImage ↔ Uri?
-
An
mxc://URI to the image. Omitted if there is no image.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override