PublicKeys class

Constructors

PublicKeys({required String ed25519, Map<String, String> additionalProperties = const {}})
PublicKeys.fromJson(Map<String, Object?> json)

Properties

additionalProperties Map<String, String>
getter/setter pair
ed25519 String
The unpadded base64-encoded ed25519 public key for the Policy Server.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override