RequestTokenResponse class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sid
↔ String
-
The session ID. Session IDs are opaque strings that must consist entirely
of the characters
[0-9a-zA-Z.=_-]. Their length must not exceed 255
characters and they must not be empty.
getter/setter pair
-
submitUrl
↔ Uri?
-
An optional field containing a URL where the client must submit the
validation token, with identical request and response parameters and error
codes to the Identity Service API's
POST /validate/email/submitToken
and POST /validate/msisdn/submitToken
endpoints (without the requirement for an access token). The homeserver
must send this token to the user (if applicable), who should then be
prompted to provide it to the client.
getter/setter pair