submitUrl property
An optional field containing a URL where the client must submit the
validation token, with identical request and response parameters and error
codes to the Identity Service API's
POST /validate/email/submitToken
and POST /validate/msisdn/submitToken
endpoints (without the requirement for an access token). The homeserver
must send this token to the user (if applicable), who should then be
prompted to provide it to the client.
If this field is not present, the client can assume that verification
will happen without the client's involvement provided the homeserver
advertises a sufficiently recent version in the GET /versions
response (ie: r0.5.0).
Implementation
Uri? submitUrl;