RoomSummary class

Constructors

RoomSummary.fromJson(Map<String, Object?> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mHeroes ↔ List<String>?
getter/setter pair
mInvitedMemberCount ↔ int?
getter/setter pair
mJoinedMemberCount ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited