ExportProgress class final

Represents progress during export

Inheritance

Constructors

ExportProgress({required ExportSource source, required int totalEvents, required int utdEvents, required int mediaEvents, required int users})

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaEvents → int
Media events count
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ExportSource
Export source
final
totalEvents → int
Total events count
finalinherited
users → int
Users count
finalinherited
utdEvents → int
Unable-to-decrypt events count
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited