ExportResult class sealed

Base class for export results

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaEvents → int
Media events count
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalEvents → int
Total events count
final
users → int
Users count
final
utdEvents → int
Unable-to-decrypt events count
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited