CallErrorCode enum
Values
- userHangup → const CallErrorCode
-
The user chose to end the call
const CallErrorCode('user_hangup') - localOfferFailed → const CallErrorCode
-
An error code when the local client failed to create an offer.
const CallErrorCode('local_offer_failed') - userMediaFailed → const CallErrorCode
-
An error code when there is no local mic/camera to use. This may be because the hardware isn't plugged in, or the user has explicitly denied access.
const CallErrorCode('user_media_failed') - unknownDevice → const CallErrorCode
-
Error code used when a call event failed to send because unknown devices were present in the room
const CallErrorCode('unknown_device') - createAnswer → const CallErrorCode
-
An answer could not be created
const CallErrorCode('create_answer') - setRemoteDescription → const CallErrorCode
-
The session description from the other side could not be set
const CallErrorCode('set_remote_description') - setLocalDescription → const CallErrorCode
-
The session description from this side could not be set
const CallErrorCode('set_local_description') - answeredElsewhere → const CallErrorCode
-
A different device answered the call
const CallErrorCode('answered_elsewhere') - iceFailed → const CallErrorCode
-
No media connection could be established to the other party
const CallErrorCode('ice_failed') - inviteTimeout → const CallErrorCode
-
The invite timed out whilst waiting for an answer
const CallErrorCode('invite_timeout') - replaced → const CallErrorCode
-
The call was replaced by another call
const CallErrorCode('replaced') - iceTimeout → const CallErrorCode
-
Signalling for the call could not be sent (other than the initial invite)
const CallErrorCode('ice_timeout') - userBusy → const CallErrorCode
-
The remote party is busy
const CallErrorCode('user_busy') - transferred → const CallErrorCode
-
We transferred the call off to somewhere else
const CallErrorCode('transferred') - unknownError → const CallErrorCode
-
Some other failure occurred that meant the client was unable to continue the call rather than the user choosing to end it.
const CallErrorCode('unknown_error')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - reason → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CallErrorCode> - A constant List of the values in this enum, in order of their declaration.