DefaultCommandOutput class
Helper class for normalized command output
This class can be used to provide a default, processable output of commands containing some generic data.
NOTE: Please be careful whether to include event IDs into the output.
If your command actually sends an event to a room, please do not include the event ID here. The default behavior of the Room.sendTextEvent is to return the event ID of the just sent event. The DefaultCommandOutput.events field is not supposed to replace/duplicate this behavior.
But if your command performs an action such as search, highlight or anything your matrix client should display different than adding an event to the Timeline, you can include the event IDs related to the command output here.
Constructors
Properties
-
custom
→ Map<
String, Object?> ? -
final
-
events
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
String> ? -
final
-
rooms
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromStdout(
String stdout) → DefaultCommandOutput?