GetMutualRoomsResponse class
Properties
-
count
↔ int
-
The number of such rooms. This is the total count even if the response is
batched and
joined doesn't include all rooms. This MAY be inaccurate
if the server is unable to calculate the exact number of rooms.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
joined
↔ List<String>
-
A list of room IDs where both the authenticated user and
user_id have a
membership of type join.
getter/setter pair
-
nextBatch
↔ String?
-
A pagination token to retrieve the next batch of results. This will be absent
if there are no more results to return.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited