count property
The number of such rooms. This is the total count even if the response is
batched and joined doesn't include all rooms. This MAY be inaccurate
if the server is unable to calculate the exact number of rooms.
Implementation
int count;
The number of such rooms. This is the total count even if the response is
batched and joined doesn't include all rooms. This MAY be inaccurate
if the server is unable to calculate the exact number of rooms.
int count;