nextBatch property
A pagination token to retrieve the next batch of results. This will be absent if there are no more results to return.
Implementation
String? nextBatch;
A pagination token to retrieve the next batch of results. This will be absent if there are no more results to return.
String? nextBatch;